# SWMManywhere

This is the documentation for SWMManywhere. It is a software that lets you
derive a synthetic urban drainage network anywhere in the world.

## Table of contents
<!-- markdownlint-disable MD007 -->
- [Home](index.md)
- [About](./paper/paper.md)
- [Quickstart](quickstart.md)
- Guides:
    - [Configuration file](config_guide.md)
    - [Parameters guide](parameters_guide.md)
    - [Graph functions](graphfcns_guide.md)
    - [Metrics guide](metrics_guide.md)
- Notebooks:
    - [Extended demo](./notebooks/extended_demo.py)
    - [Real world demo](./notebooks/validation_demo.py)
    - [Using custom data](./notebooks/custom_data_demo.py)
- [Contributing](CONTRIBUTING.md)
- [API reference](reference-overview.md)
    - [SWMManywhere](reference.md)
    - [Graph utilities](reference-graph-utilities.md)
    - [Geospatial utilities](reference-geospatial-utilities.md)
    - [Metric utilities](reference-metric-utilities.md)
    - [Logging](reference-logging.md)
    - [Parameters](reference-parameters.md)
    - [FilePaths](reference-filepaths.md)
    - [Post processing](reference-post-processing.md)
    - [Preprocessing](reference-preprocessing.md)
    - [Config](reference-defs.md)
- [Coverage report](https://app.codecov.io/gh/ImperialCollegeLondon/SWMManywhere)
<!---  --->